====================
Developing batou_scm
====================

:Author:
    `gocept <http://gocept.com/>`_ <mail@gocept.com>

:PyPI page:
    https://pypi.python.org/pypi/batou_scm

:Issues:
    https://github.com/flyingcircus/batou_scm/issues

:Source code:
    https://github.com/flyingcircus/batou_scm

:Current change log:
    https://raw.githubusercontent.com/flyingcircus/batou_scm/main/CHANGES.rst
